diff --git a/Code/IO/otbDEMHandler.cxx b/Code/IO/otbDEMHandler.cxx
index 4f280524617757a75a5d1e15a560593a62c7021a..7b13c8f829ad7b5427ee8df728428d2d934922f7 100644
--- a/Code/IO/otbDEMHandler.cxx
+++ b/Code/IO/otbDEMHandler.cxx
@@ -15,10 +15,10 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __otbDEMReader_cxx
-#define __otbDEMReader_cxx
+#ifndef __otbDEMHandler_cxx
+#define __otbDEMHandler_cxx
 
-#include "otbDEMReader.h"
+#include "otbDEMHandler.h"
 #include "otbMacro.h"
 
 namespace otb
@@ -26,16 +26,16 @@ namespace otb
 
 
 
-DEMReader
-::DEMReader()
+DEMHandler
+::DEMHandler()
 {
 	m_ElevManager=ossimElevManager::instance();
 }
   
 	
 
-DEMReader
-::~DEMReader()
+DEMHandler
+::~DEMHandler()
 {
 	// not needed, m_ElevManager created with instance() method
 	// delete m_ElevManager;
@@ -44,7 +44,7 @@ DEMReader
 
 
 bool 
-DEMReader
+DEMHandler
 ::OpenDEMDirectory(const char* DEMDirectory)
 {
 	ossimFilename ossimDEMDir;
@@ -59,7 +59,7 @@ DEMReader
 
 
 double 
-DEMReader
+DEMHandler
 ::GetHeightAboveMSL(const PointType& geoPoint)
 {
 	float height;
@@ -72,12 +72,12 @@ DEMReader
 
 
 void 
-DEMReader
+DEMHandler
 ::PrintSelf(std::ostream& os, Indent indent) const
 {
   Superclass::PrintSelf(os,indent);
  
-  os << indent << "DEMReader" << std::endl;
+  os << indent << "DEMHandler" << std::endl;
 }
 
 } // namespace otb
diff --git a/Code/IO/otbDEMHandler.h b/Code/IO/otbDEMHandler.h
index f0c186a16e54e68049309040864965912a0075b9..b9a8a97b02fbca0a208872a185eb14358638bb52 100755
--- a/Code/IO/otbDEMHandler.h
+++ b/Code/IO/otbDEMHandler.h
@@ -15,8 +15,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __otbDEMReader_h
-#define __otbDEMReader_h
+#ifndef __otbDEMHandler_h
+#define __otbDEMHandler_h
 
 #include "itkIndent.h"
 #include "itkImageSource.h"
@@ -30,7 +30,7 @@
 
 namespace otb
 {
-/** \class DEMReader
+/** \class DEMHandler
  *
  * \brief Class for Reading a DEM data
  *
@@ -41,12 +41,12 @@ namespace otb
  *
  */
 
-class ITK_EXPORT DEMReader: public itk::Object
+class ITK_EXPORT DEMHandler: public itk::Object
 {
 public :
 /** Standard class typedefs. */
   typedef itk::Indent														Indent;
-  typedef DEMReader                             Self;
+  typedef DEMHandler                             Self;
   typedef itk::Object														Superclass;
   typedef itk::SmartPointer<Self>               Pointer;
   typedef itk::SmartPointer<const Self>         ConstPointer;
@@ -57,7 +57,7 @@ public :
   itkNewMacro(Self);
   
 	/** Run-time type information (and related methods). */
-  itkTypeMacro(DEMReader,Object);
+  itkTypeMacro(DEMHandler,Object);
   	                                      
 	/** Try to open the DEM directory. */
 	bool OpenDEMDirectory(const char* DEMDirectory);         
@@ -66,8 +66,8 @@ public :
 	virtual double GetHeightAboveMSL(const PointType& geoPoint);     
 
 protected:
-	DEMReader();
-	~DEMReader();
+	DEMHandler();
+	~DEMHandler();
 
 	void PrintSelf(std::ostream& os, Indent indent) const;
 
diff --git a/Code/Projections/otbInverseSensorModel.h b/Code/Projections/otbInverseSensorModel.h
index 0d7528bcb9faba3e1a5aa983e93eb25866645c5c..25401473a7c779967f71c527337b2d1725541d34 100644
--- a/Code/Projections/otbInverseSensorModel.h
+++ b/Code/Projections/otbInverseSensorModel.h
@@ -19,7 +19,7 @@
 #define __otbInverseSensorModel_h
 
 #include "otbSensorModelBase.h"
-#include "otbDEMReader.h"
+#include "otbDEMHandler.h"
 
 #include "itkMacro.h"
 #include "itkSmartPointer.h"
@@ -66,7 +66,7 @@ public :
 	typedef typename Superclass::OutputPointType           OutputPointType; 
 	
 	//typedef otb::Image<double, NInputDimensions>	 ImageType;
-	typedef DEMReader													 						 DEMHandlerType;
+	typedef DEMHandler													 						 DEMHandlerType;
 	typedef typename DEMHandlerType::Pointer							 DEMHandlerPointerType;     
 
 	/** Method for creation through the object factory. */
diff --git a/Testing/Code/Projections/otbOrthoRectificationFilter.cxx b/Testing/Code/Projections/otbOrthoRectificationFilter.cxx
index 9a30f0cd04154d8303cfc0048cf11cae56b572ec..a773716f0be75df4ee4a06d714020906be299fcd 100644
--- a/Testing/Code/Projections/otbOrthoRectificationFilter.cxx
+++ b/Testing/Code/Projections/otbOrthoRectificationFilter.cxx
@@ -76,8 +76,7 @@ int otbOrthoRectificationFilter( int argc, char* argv[] )
         typedef otb::ImageFileReader<ImageType>  ReaderType;
 //        typedef otb::ImageFileWriter<ImageType>  WriterType;
         typedef otb::StreamingImageFileWriter<ImageType>  WriterType;
-				typedef itk::Transform<double,2,2> TransformType;
-        
+	       
 //				typedef otb::InverseSensorModel<double> ModelType;
 			  typedef itk::LinearInterpolateImageFunction<ImageType, double > InterpolatorType;
 				
diff --git a/Testing/Code/Projections/otbSensorImageDEMToCarto.cxx b/Testing/Code/Projections/otbSensorImageDEMToCarto.cxx
index 90266781974c1c96b4450960178093d5aeaf2f9f..9c073ed28e8592e872488d99ce38f72616fca8cf 100755
--- a/Testing/Code/Projections/otbSensorImageDEMToCarto.cxx
+++ b/Testing/Code/Projections/otbSensorImageDEMToCarto.cxx
@@ -3,7 +3,7 @@
  * PURPOSE:
  *
  * Application pour projeter une r�gion d'une image en coordonn�es g�ographiques 
  * en utilisant un Interpolator+regionextractor+Iterator+DEMReader. 
  * Prise en compte du MNT
  */
 
@@ -26,7 +26,7 @@
 
 #include "otbMapProjections.h"
 #include "otbMapProjection.h"
-#include "otbDEMReader.h"
+#include "otbDEMHandler.h"
 
 int otbSensorImageDEMToCarto( int argc, char* argv[] )
 {
@@ -121,11 +121,11 @@ ossimKeywordlist geom_kwl;
       ModelType::OutputPointType inputpoint;
 
 /********************************************************/
-/*                Cr�ation d'un DEMReader               */
+/*                Cr�ation d'un DEMHandler               */
 /********************************************************/
 
-typedef otb::DEMReader				  DEMReaderType;
-DEMReaderType::Pointer		      otbElevManager=DEMReaderType::New();
+typedef otb::DEMHandler				  DEMHandlerType;
+DEMHandlerType::Pointer		      otbElevManager=DEMHandlerType::New();
 double height;
 
 /********************************************************/
@@ -3,7 +3,7 @@
  *
  * Application pour projeter une r�gion d'une image en coordonn�es g�ographiques 
- * en utilisant un Interpolator+regionextractor+Iterator+DEMReader. 
+ * en utilisant un Interpolator+regionextractor+Iterator+DEMHandler. 
  * Prise en compte du MNT
  */